You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@geode.apache.org by kl...@apache.org on 2017/05/08 22:22:32 UTC

[3/4] geode git commit: GEODE-2738: Corrected misspellibng of "occured" to "occurred"

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/internal/cache/wan/AbstractGatewaySenderEventProcessor.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/internal/cache/wan/AbstractGatewaySenderEventProcessor.java b/geode-core/src/main/java/org/apache/geode/internal/cache/wan/AbstractGatewaySenderEventProcessor.java
index dfbd664..263c446 100644
--- a/geode-core/src/main/java/org/apache/geode/internal/cache/wan/AbstractGatewaySenderEventProcessor.java
+++ b/geode-core/src/main/java/org/apache/geode/internal/cache/wan/AbstractGatewaySenderEventProcessor.java
@@ -880,7 +880,7 @@ public abstract class AbstractGatewaySenderEventProcessor extends Thread {
               filter.afterAcknowledgement((GatewaySenderEventImpl) o);
             } catch (Exception e) {
               logger.fatal(LocalizedMessage.create(
-                  LocalizedStrings.GatewayEventFilter_EXCEPTION_OCCURED_WHILE_HANDLING_CALL_TO_0_AFTER_ACKNOWLEDGEMENT_FOR_EVENT_1,
+                  LocalizedStrings.GatewayEventFilter_EXCEPTION_OCCURRED_WHILE_HANDLING_CALL_TO_0_AFTER_ACKNOWLEDGEMENT_FOR_EVENT_1,
                   new Object[] {filter.toString(), o}), e);
             }
           }
@@ -965,7 +965,7 @@ public abstract class AbstractGatewaySenderEventProcessor extends Thread {
             filter.afterAcknowledgement(event);
           } catch (Exception e) {
             logger.fatal(LocalizedMessage.create(
-                LocalizedStrings.GatewayEventFilter_EXCEPTION_OCCURED_WHILE_HANDLING_CALL_TO_0_AFTER_ACKNOWLEDGEMENT_FOR_EVENT_1,
+                LocalizedStrings.GatewayEventFilter_EXCEPTION_OCCURRED_WHILE_HANDLING_CALL_TO_0_AFTER_ACKNOWLEDGEMENT_FOR_EVENT_1,
                 new Object[] {filter.toString(), event}), e);
           }
         }

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/internal/cache/wan/GatewayReceiverStats.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/internal/cache/wan/parallel/ParallelQueueBatchRemovalMessage.java b/geode-core/src/main/java/org/apache/geode/internal/cache/wan/parallel/ParallelQueueBatchRemovalMessage.java
index 10a83b2..47005c3 100644
--- a/geode-core/src/main/java/org/apache/geode/internal/cache/wan/parallel/ParallelQueueBatchRemovalMessage.java
+++ b/geode-core/src/main/java/org/apache/geode/internal/cache/wan/parallel/ParallelQueueBatchRemovalMessage.java
@@ -97,7 +97,7 @@ public class ParallelQueueBatchRemovalMessage extends PartitionMessage {
                   }
                 } catch (Exception e) {
                   logger.fatal(LocalizedMessage.create(
-                      LocalizedStrings.GatewayEventFilter_EXCEPTION_OCCURED_WHILE_HANDLING_CALL_TO_0_AFTER_ACKNOWLEDGEMENT_FOR_EVENT_1,
+                      LocalizedStrings.GatewayEventFilter_EXCEPTION_OCCURRED_WHILE_HANDLING_CALL_TO_0_AFTER_ACKNOWLEDGEMENT_FOR_EVENT_1,
                       new Object[] {filter.toString(), eventForFilter}), e);
                 }
               }

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/internal/cache/wan/parallel/ParallelQueueRemovalMessage.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/internal/cache/wan/parallel/ParallelQueueRemovalMessage.java b/geode-core/src/main/java/org/apache/geode/internal/cache/wan/parallel/ParallelQueueRemovalMessage.java
index 921af9c..a7f224f 100644
--- a/geode-core/src/main/java/org/apache/geode/internal/cache/wan/parallel/ParallelQueueRemovalMessage.java
+++ b/geode-core/src/main/java/org/apache/geode/internal/cache/wan/parallel/ParallelQueueRemovalMessage.java
@@ -174,7 +174,7 @@ public class ParallelQueueRemovalMessage extends PooledDistributionMessage {
         }
       } catch (Exception e) {
         logger.fatal(LocalizedMessage.create(
-            LocalizedStrings.GatewayEventFilter_EXCEPTION_OCCURED_WHILE_HANDLING_CALL_TO_0_AFTER_ACKNOWLEDGEMENT_FOR_EVENT_1,
+            LocalizedStrings.GatewayEventFilter_EXCEPTION_OCCURRED_WHILE_HANDLING_CALL_TO_0_AFTER_ACKNOWLEDGEMENT_FOR_EVENT_1,
             new Object[] {filter.toString(), eventForFilter}), e);
       }
     }
@@ -247,7 +247,7 @@ public class ParallelQueueRemovalMessage extends PooledDistributionMessage {
         }
       } catch (Exception e) {
         logger.fatal(LocalizedMessage.create(
-            LocalizedStrings.GatewayEventFilter_EXCEPTION_OCCURED_WHILE_HANDLING_CALL_TO_0_AFTER_ACKNOWLEDGEMENT_FOR_EVENT_1,
+            LocalizedStrings.GatewayEventFilter_EXCEPTION_OCCURRED_WHILE_HANDLING_CALL_TO_0_AFTER_ACKNOWLEDGEMENT_FOR_EVENT_1,
             new Object[] {filter.toString(), eventForFilter}), e);
       }
     }

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/internal/cache/wan/serial/BatchDestroyOperation.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/internal/cache/wan/serial/BatchDestroyOperation.java b/geode-core/src/main/java/org/apache/geode/internal/cache/wan/serial/BatchDestroyOperation.java
index a368b60..d38b2c7 100644
--- a/geode-core/src/main/java/org/apache/geode/internal/cache/wan/serial/BatchDestroyOperation.java
+++ b/geode-core/src/main/java/org/apache/geode/internal/cache/wan/serial/BatchDestroyOperation.java
@@ -115,7 +115,7 @@ public class BatchDestroyOperation extends DistributedCacheOperation {
                 }
               } catch (Exception e) {
                 logger.fatal(LocalizedMessage.create(
-                    LocalizedStrings.GatewayEventFilter_EXCEPTION_OCCURED_WHILE_HANDLING_CALL_TO_0_AFTER_ACKNOWLEDGEMENT_FOR_EVENT_1,
+                    LocalizedStrings.GatewayEventFilter_EXCEPTION_OCCURRED_WHILE_HANDLING_CALL_TO_0_AFTER_ACKNOWLEDGEMENT_FOR_EVENT_1,
                     new Object[] {filter.toString(), eventForFilter}), e);
               }
             }

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/internal/datasource/FacetsJCAConnectionManagerImpl.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/internal/datasource/FacetsJCAConnectionManagerImpl.java b/geode-core/src/main/java/org/apache/geode/internal/datasource/FacetsJCAConnectionManagerImpl.java
index 318121c..d581ceb 100644
--- a/geode-core/src/main/java/org/apache/geode/internal/datasource/FacetsJCAConnectionManagerImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/internal/datasource/FacetsJCAConnectionManagerImpl.java
@@ -181,7 +181,7 @@ public class FacetsJCAConnectionManagerImpl
         // mannPoolCache.destroyPooledConnection(conn);
       } catch (Exception ex) {
         String exception =
-            "FacetsJCAConnectionManagerImpl::connectionErrorOccured: Exception occured due to "
+            "FacetsJCAConnectionManagerImpl::connectionErrorOccurred: Exception occurred due to "
                 + ex.getMessage();
         if (logger.isDebugEnabled()) {
           logger.debug(exception, ex);
@@ -206,7 +206,7 @@ public class FacetsJCAConnectionManagerImpl
         }
       } catch (Exception se) {
         String exception =
-            "FacetsJCAConnectionManagerImpl::connectionClosed: Exception occured due to "
+            "FacetsJCAConnectionManagerImpl::connectionClosed: Exception occurred due to "
                 + se.getMessage();
         if (logger.isDebugEnabled()) {
           logger.debug(exception, se);

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/internal/datasource/GemFireConnPooledDataSource.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/internal/datasource/GemFireConnPooledDataSource.java b/geode-core/src/main/java/org/apache/geode/internal/datasource/GemFireConnPooledDataSource.java
index b9ea3f6..0a51165 100644
--- a/geode-core/src/main/java/org/apache/geode/internal/datasource/GemFireConnPooledDataSource.java
+++ b/geode-core/src/main/java/org/apache/geode/internal/datasource/GemFireConnPooledDataSource.java
@@ -157,7 +157,7 @@ public class GemFireConnPooledDataSource extends AbstractDataSource
         provider.returnAndExpireConnection(conn);
       } catch (Exception ex) {
         String exception =
-            "GemFireConnPooledDataSource::connectionErrorOccured:error in returning and expiring connection due to "
+            "GemFireConnPooledDataSource::connectionErrorOccurred:error in returning and expiring connection due to "
                 + ex;
         if (logger.isDebugEnabled()) {
           logger.debug(exception, ex);

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/internal/datasource/GemFireTransactionDataSource.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/internal/datasource/GemFireTransactionDataSource.java b/geode-core/src/main/java/org/apache/geode/internal/datasource/GemFireTransactionDataSource.java
index 5ef3efd..d940095 100644
--- a/geode-core/src/main/java/org/apache/geode/internal/datasource/GemFireTransactionDataSource.java
+++ b/geode-core/src/main/java/org/apache/geode/internal/datasource/GemFireTransactionDataSource.java
@@ -166,7 +166,7 @@ public class GemFireTransactionDataSource extends AbstractDataSource
         provider.returnConnection(conn);
       } catch (Exception e) {
         String exception =
-            "GemFireTransactionDataSource::connectionClosed: Exception occured due to " + e;
+            "GemFireTransactionDataSource::connectionClosed: Exception occurred due to " + e;
         if (logger.isDebugEnabled()) {
           logger.debug(exception, e);
         }
@@ -187,7 +187,8 @@ public class GemFireTransactionDataSource extends AbstractDataSource
         provider.returnAndExpireConnection(conn);
       } catch (Exception ex) {
         String exception =
-            "GemFireTransactionDataSource::connectionErrorOccured: Exception occured due to " + ex;
+            "GemFireTransactionDataSource::connectionErrorOccurred: Exception occurred due to "
+                + ex;
         if (logger.isDebugEnabled()) {
           logger.debug(exception, ex);
         }
@@ -214,7 +215,7 @@ public class GemFireTransactionDataSource extends AbstractDataSource
       }
     } catch (Exception ex) {
       Exception e = new Exception(
-          LocalizedStrings.GemFireTransactionDataSource_GEMFIRETRANSACTIONDATASOURCEREGISTERTRANXCONNECTION_EXCEPTION_IN_REGISTERING_THE_XARESOURCE_WITH_THE_TRANSACTIONEXCEPTION_OCCURED_0
+          LocalizedStrings.GemFireTransactionDataSource_GEMFIRETRANSACTIONDATASOURCEREGISTERTRANXCONNECTION_EXCEPTION_IN_REGISTERING_THE_XARESOURCE_WITH_THE_TRANSACTIONEXCEPTION_OCCURRED_0
               .toLocalizedString(ex));
       e.initCause(ex);
       throw e;

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/internal/datasource/JCAConnectionManagerImpl.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/internal/datasource/JCAConnectionManagerImpl.java b/geode-core/src/main/java/org/apache/geode/internal/datasource/JCAConnectionManagerImpl.java
index d54d1a1..d5f66d0 100755
--- a/geode-core/src/main/java/org/apache/geode/internal/datasource/JCAConnectionManagerImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/internal/datasource/JCAConnectionManagerImpl.java
@@ -159,7 +159,7 @@ public class JCAConnectionManagerImpl implements ConnectionManager, ConnectionEv
         // mannPoolCache.destroyPooledConnection(conn);
       } catch (Exception ex) {
         String exception =
-            "JCAConnectionManagerImpl::connectionErrorOccured: Exception occured due to " + ex;
+            "JCAConnectionManagerImpl::connectionErrorOccurred: Exception occurred due to " + ex;
         if (logger.isDebugEnabled()) {
           logger.debug(exception, ex);
         }
@@ -186,7 +186,7 @@ public class JCAConnectionManagerImpl implements ConnectionManager, ConnectionEv
         }
       } catch (Exception se) {
         String exception =
-            "JCAConnectionManagerImpl::connectionClosed: Exception occured due to " + se;
+            "JCAConnectionManagerImpl::connectionClosed: Exception occurred due to " + se;
         if (logger.isDebugEnabled()) {
           logger.debug(exception, se);
         }

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/internal/i18n/LocalizedStrings.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/internal/i18n/LocalizedStrings.java b/geode-core/src/main/java/org/apache/geode/internal/i18n/LocalizedStrings.java
index 94898cf..85042da 100755
--- a/geode-core/src/main/java/org/apache/geode/internal/i18n/LocalizedStrings.java
+++ b/geode-core/src/main/java/org/apache/geode/internal/i18n/LocalizedStrings.java
@@ -522,11 +522,11 @@ public class LocalizedStrings {
       new StringId(1294, "ContextImpl::lookup::Error while looking up {0}");
   public static final StringId CqAttributesFactory_EXCEPTION_CLOSING_CQ_LISTENER_ERROR_0 =
       new StringId(1295, "Exception closing CQ Listener Error: {0}");
-  public static final StringId CqAttributesFactory_EXCEPTION_OCCURED_WHILE_CLOSING_CQ_LISTENER_ERROR_0 =
+  public static final StringId CqAttributesFactory_EXCEPTION_OCCURRED_WHILE_CLOSING_CQ_LISTENER_ERROR_0 =
       new StringId(1296, "Exception occurred while closing CQ Listener Error: {0}");
-  public static final StringId CqAttributesFactory_RUNTIME_EXCEPTION_OCCURED_CLOSING_CQ_LISTENER_ERROR_0 =
+  public static final StringId CqAttributesFactory_RUNTIME_EXCEPTION_OCCURRED_CLOSING_CQ_LISTENER_ERROR_0 =
       new StringId(1297, "Runtime Exception occurred closing CQ Listener Error: {0}");
-  public static final StringId CqAttributesFactory_RUNTIME_EXCEPTION_OCCURED_WHILE_CLOSING_CQ_LISTENER_ERROR_0 =
+  public static final StringId CqAttributesFactory_RUNTIME_EXCEPTION_OCCURRED_WHILE_CLOSING_CQ_LISTENER_ERROR_0 =
       new StringId(1298, "Runtime Exception occurred while closing CQ Listener Error: {0}");
   public static final StringId CqQueryImpl_FAILED_TO_STORE_CONTINUOUS_QUERY_IN_THE_REPOSITORY_CQNAME_0_1 =
       new StringId(1299, "Failed to store Continuous Query in the repository. CqName: {0} {1}");
@@ -1037,7 +1037,7 @@ public class LocalizedStrings {
   public static final StringId GlobalTransaction_GLOBALTRANSACTION_CONSTRUCTOR_ERROR_WHILE_TRYING_TO_CREATE_XID_DUE_TO_0 =
       new StringId(1645,
           "GlobalTransaction::Constructor::Error while trying to create Xid due to {0}");
-  public static final StringId GlobalTransaction_GLOBATRANSACTION_EXPIREGTX_ERROR_OCCURED_WHILE_REMOVING_TRANSACTIONAL_MAPPINGS_0 =
+  public static final StringId GlobalTransaction_GLOBATRANSACTION_EXPIREGTX_ERROR_OCCURRED_WHILE_REMOVING_TRANSACTIONAL_MAPPINGS_0 =
       new StringId(1646,
           "GlobaTransaction::expireGTX:Error occurred while removing transactional mappings {0}");
   public static final StringId GlobalTransaction_TRANSACTION_0_HAS_TIMED_OUT =
@@ -1054,7 +1054,7 @@ public class LocalizedStrings {
   public static final StringId HARegionQueue_DISPATCHEDANDCURRENTEVENTSEXPIREORUPDATE_UNEXPECTEDLY_ENCOUNTERED_EXCEPTION_WHILE_UPDATING_EXPIRY_ID_FOR_THREADIDENTIFIER_0 =
       new StringId(1651,
           "DispatchedAndCurrentEvents::expireOrUpdate: Unexpectedly encountered exception while updating expiry ID for ThreadIdentifier={0}");
-  public static final StringId HARegionQueue_EXCEPTION_OCCURED_WHILE_TRYING_TO_SET_THE_LAST_DISPATCHED_ID =
+  public static final StringId HARegionQueue_EXCEPTION_OCCURRED_WHILE_TRYING_TO_SET_THE_LAST_DISPATCHED_ID =
       new StringId(1652, "Exception occurred while trying to set the last dispatched id");
   public static final StringId HARegionQueue_HAREGIONQUEUECREATECACHELISTNEREXCEPTION_IN_THE_EXPIRY_THREAD =
       new StringId(1653, "HAREgionQueue::createCacheListner::Exception in the expiry thread");
@@ -1063,7 +1063,7 @@ public class LocalizedStrings {
       new StringId(1655, "HARegionQueue and its derived class do not support this operation ");
   public static final StringId ConnectionTable_THE_DISTRIBUTED_SYSTEM_IS_SHUTTING_DOWN =
       new StringId(1656, "The distributed system is shutting down");
-  public static final StringId HARegionQueue_INTERRUPTEDEXCEPTION_OCCURED_IN_QUEUEREMOVALTHREAD_WHILE_WAITING =
+  public static final StringId HARegionQueue_INTERRUPTEDEXCEPTION_OCCURRED_IN_QUEUEREMOVALTHREAD_WHILE_WAITING =
       new StringId(1657, "InterruptedException occurred in QueueRemovalThread  while waiting ");
   public static final StringId HealthMonitorImpl_UNEXPECTED_STOP_OF_HEALTH_MONITOR =
       new StringId(1658, "Unexpected stop of health monitor");
@@ -1101,9 +1101,9 @@ public class LocalizedStrings {
 
   public static final StringId InternalDistributedSystem_DISCONNECT_LISTENER_STILL_RUNNING__0 =
       new StringId(1685, "Disconnect listener still running: {0}");
-  public static final StringId InternalDistributedSystem_EXCEPTION_OCCURED_WHILE_TRYING_TO_CONNECT_THE_SYSTEM_DURING_RECONNECT =
+  public static final StringId InternalDistributedSystem_EXCEPTION_OCCURRED_WHILE_TRYING_TO_CONNECT_THE_SYSTEM_DURING_RECONNECT =
       new StringId(1686, "Exception occurred while trying to connect the system during reconnect");
-  public static final StringId InternalDistributedSystem_EXCEPTION_OCCURED_WHILE_TRYING_TO_CREATE_THE_CACHE_DURING_RECONNECT =
+  public static final StringId InternalDistributedSystem_EXCEPTION_OCCURRED_WHILE_TRYING_TO_CREATE_THE_CACHE_DURING_RECONNECT =
       new StringId(1687, "Exception occurred while trying to create the cache during reconnect");
   public static final StringId InternalDistributedSystem_INTERRUPTED_WHILE_PROCESSING_DISCONNECT_LISTENER =
       new StringId(1688, "Interrupted while processing disconnect listener");
@@ -1918,7 +1918,7 @@ public class LocalizedStrings {
   public static final StringId AbstractDistributionConfig_COULD_NOT_SET_0_RECHARGETHRESHOLD_TO_1_BECAUSE_ITS_VALUE_CAN_NOT_BE_LESS_THAN_2 =
       new StringId(2167,
           "Could not set \"{0}.rechargeThreshold\" to \"{1}\" because its value can not be less than \"{2}\"");
-  public static final StringId UNCAUGHT_EXCEPTION_IN_THREAD_0_THIS_MESSAGE_CAN_BE_DISREGARDED_IF_IT_OCCURED_DURING_AN_APPLICATION_SERVER_SHUTDOWN_THE_EXCEPTION_MESSAGE_WAS_1 =
+  public static final StringId UNCAUGHT_EXCEPTION_IN_THREAD_0_THIS_MESSAGE_CAN_BE_DISREGARDED_IF_IT_OCCURRED_DURING_AN_APPLICATION_SERVER_SHUTDOWN_THE_EXCEPTION_MESSAGE_WAS_1 =
       new StringId(2168,
           "Uncaught exception in thread {0} this message can be disregarded if it occurred during an Application Server shutdown. The Exception message was: {1}");
 
@@ -2855,7 +2855,7 @@ public class LocalizedStrings {
   public static final StringId GemFireTransactionDataSource_GEMFIRETRANSACTIONDATASOURCEGETCONNECTIONNO_VALID_CONNECTION_AVAILABLE =
       new StringId(2707,
           "GemFireTransactionDataSource::getConnection::No valid Connection available");
-  public static final StringId GemFireTransactionDataSource_GEMFIRETRANSACTIONDATASOURCEREGISTERTRANXCONNECTION_EXCEPTION_IN_REGISTERING_THE_XARESOURCE_WITH_THE_TRANSACTIONEXCEPTION_OCCURED_0 =
+  public static final StringId GemFireTransactionDataSource_GEMFIRETRANSACTIONDATASOURCEREGISTERTRANXCONNECTION_EXCEPTION_IN_REGISTERING_THE_XARESOURCE_WITH_THE_TRANSACTIONEXCEPTION_OCCURRED_0 =
       new StringId(2708,
           "GemFireTransactionDataSource-registerTranxConnection(). Exception in registering the XAResource with the Transaction.Exception occurred= {0}");
   public static final StringId GemFireTransactionDataSource_GEMFIRETRANSACTIONDATASOURCEXADATASOURCE_CLASS_OBJECT_IS_NULL_OR_CONFIGUREDDATASOURCEPROPERTIES_OBJECT_IS_NULL =
@@ -3042,7 +3042,7 @@ public class LocalizedStrings {
       new StringId(2847, "Class  {0}  could not be instantiated.");
   public static final StringId LocalRegion_CLASS_0_NOT_FOUND_IN_CLASSPATH =
       new StringId(2848, "Class  {0}  not found in classpath.");
-  public static final StringId LocalRegion_EXCEPTION_OCCURED_WHILE_RE_CREATING_INDEX_DATA_ON_CLEARED_REGION =
+  public static final StringId LocalRegion_EXCEPTION_OCCURRED_WHILE_RE_CREATING_INDEX_DATA_ON_CLEARED_REGION =
       new StringId(2849, "Exception occurred while re creating index data on cleared region.");
   public static final StringId LocalRegion_FAILED_ENLISTEMENT_WITH_TRANSACTION_0 =
       new StringId(2850, "Failed enlistement with transaction \"{0}\"");
@@ -3459,7 +3459,7 @@ public class LocalizedStrings {
 
   public static final StringId PartitionedRegion_TIME_OUT_LOOKING_FOR_TARGET_NODE_FOR_DESTROY_WAITED_0_MS =
       new StringId(3093, "Time out looking for target node for destroy; waited  {0}  ms");
-  public static final StringId PartitionedRegion_UNEXPECTED_QUERY_EXCEPTION_OCCURED_DURING_QUERY_EXECUTION_0 =
+  public static final StringId PartitionedRegion_UNEXPECTED_QUERY_EXCEPTION_OCCURRED_DURING_QUERY_EXECUTION_0 =
       new StringId(3094, "Unexpected query exception occurred during query execution  {0}");
   public static final StringId PooledExecutorWithDMStats_EXECUTOR_HAS_BEEN_SHUTDOWN =
       new StringId(3095, "executor has been shutdown");
@@ -4442,14 +4442,14 @@ public class LocalizedStrings {
   public static final StringId GlobalTransaction_GLOBALTRANSACTION_ENLISTRESOURCE_CANNOT_ENLIST_A_RESOURCE_TO_A_TRANSACTION_WHICH_IS_NOT_ACTIVE =
       new StringId(3717,
           "GlobalTransaction::enlistResource::Cannot enlist a resource to a transaction which is not active");
-  public static final StringId GlobalTransaction_GLOBALTRANSACTION_ENLISTRESOURCE_EXCEPTION_OCCURED_IN_TRYING_TO_SET_XARESOURCE_TIMEOUT_DUE_TO_0_ERROR_CODE_1 =
+  public static final StringId GlobalTransaction_GLOBALTRANSACTION_ENLISTRESOURCE_EXCEPTION_OCCURRED_IN_TRYING_TO_SET_XARESOURCE_TIMEOUT_DUE_TO_0_ERROR_CODE_1 =
       new StringId(3718,
           "GlobalTransaction::enlistResource:Exception occurred in trying to set XAResource timeout due to {0} Error Code = {1}");
   public static final StringId GlobalTransaction_ERROR_WHILE_DELISTING_XARESOURCE_0_1 =
       new StringId(3719, "error while delisting XAResource {0} {1}");
   public static final StringId GlobalTransaction_GLOBATRANSACTION_RESUME_RESUME_NOT_SUCCESFUL_DUE_TO_0 =
       new StringId(3720, "GlobaTransaction::resume:Resume not succesful due to {0}");
-  public static final StringId GlobalTransaction_EXCEPTION_OCCURED_WHILE_TRYING_TO_SET_THE_XARESOURCE_TIMEOUT_DUE_TO_0_ERROR_CODE_1 =
+  public static final StringId GlobalTransaction_EXCEPTION_OCCURRED_WHILE_TRYING_TO_SET_THE_XARESOURCE_TIMEOUT_DUE_TO_0_ERROR_CODE_1 =
       new StringId(3721,
           "Exception occurred while trying to set the XAResource TimeOut due to {0} Error code = {1}");
   public static final StringId SmHelper_NATIVE_CODE_UNAVAILABLE =
@@ -5275,7 +5275,7 @@ public class LocalizedStrings {
       new StringId(4159, "AuthorizeRequest: Client[{0}] is setting authorization callback to {1}.");
   public static final StringId AuthorizeRequest_NOT_AUTHORIZED_TO_PERFORM_GET_OPERATION_ON_REGION_0 =
       new StringId(4160, "Not authorized to perform GET operation on region [{0}]");
-  public static final StringId CqEventImpl_EXCEPTION_OCCURED_WHILE_APPLYING_QUERY_ON_A_CACHE_EVENT =
+  public static final StringId CqEventImpl_EXCEPTION_OCCURRED_WHILE_APPLYING_QUERY_ON_A_CACHE_EVENT =
       new StringId(4161, "Exception occurred while applying query on a cache event.");
   public static final StringId AuthorizeRequest_NOT_AUTHORIZED_TO_PERFORM_PUT_OPERATION_ON_REGION_0 =
       new StringId(4162, "Not authorized to perform PUT operation on region {0}");
@@ -5672,7 +5672,7 @@ public class LocalizedStrings {
           "recursiveDestroyRegion: postDestroyRegion failed due to cache closure. region = {0}");
   public static final StringId LocalRegion_RECURSIVEDESTROYREGION_PROBLEM_IN_CACHEWRITEBEFOREREGIONDESTROY =
       new StringId(4402, "recursiveDestroyRegion: problem in cacheWriteBeforeRegionDestroy");
-  public static final StringId LocalRegion_A_DISKACCESSEXCEPTION_HAS_OCCURED_WHILE_WRITING_TO_THE_DISK_FOR_REGION_0_THE_REGION_WILL_BE_CLOSED =
+  public static final StringId LocalRegion_A_DISKACCESSEXCEPTION_HAS_OCCURRED_WHILE_WRITING_TO_THE_DISK_FOR_REGION_0_THE_REGION_WILL_BE_CLOSED =
       new StringId(4403,
           "A DiskAccessException has occurred while writing to the disk for region {0}. The region will be closed.");
   public static final StringId PoolImpl_DESTROYING_CONNECTION_POOL_0 =
@@ -6129,7 +6129,7 @@ public class LocalizedStrings {
       new StringId(4679, "InstantiatorRecoveryTask - Error ClassNotFoundException: {0}");
   public static final StringId ResourceAdvisor_MEMBER_CAUGHT_EXCEPTION_PROCESSING_PROFILE =
       new StringId(4682, "This member caught exception processing profile {0} {1}");
-  public static final StringId MemoryMonitor_EXCEPTION_OCCURED_WHEN_NOTIFYING_LISTENERS =
+  public static final StringId MemoryMonitor_EXCEPTION_OCCURRED_WHEN_NOTIFYING_LISTENERS =
       new StringId(4683, "Exception occurred when notifying listeners ");
   public static final StringId CacheXmlParser_A_0_IS_NOT_DATA_SERIALIZABLE = new StringId(4684,
       "The class {0}, presented for instantiator registration is not an instance of DataSerializable and cannot be registered.");
@@ -6519,7 +6519,7 @@ public class LocalizedStrings {
       new StringId(4903, "Received cluster configuration from the locator");
   public static final StringId GemFireCache_SHARED_CONFIGURATION_NOT_AVAILABLE =
       new StringId(4904, "cluster configuration service not available");
-  public static final StringId GemFireCache_EXCEPTION_OCCURED_WHILE_DEPLOYING_JARS_FROM_SHARED_CONDFIGURATION =
+  public static final StringId GemFireCache_EXCEPTION_OCCURRED_WHILE_DEPLOYING_JARS_FROM_SHARED_CONDFIGURATION =
       new StringId(4905,
           "Exception while deploying the jars received as a part of cluster Configuration");
   public static final StringId GemFireCache_NO_LOCATORS_FOUND_WITH_SHARED_CONFIGURATION =
@@ -6783,7 +6783,7 @@ public class LocalizedStrings {
       new StringId(5090, "-disable-default-server  Do not add a default <cache-server>");
   public static final StringId Oplog_REMOVING_INCOMPLETE_KRF =
       new StringId(5091, "Removing incomplete krf {0} for oplog {1}, disk store \"{2}\"");
-  public static final StringId PlaceHolderDiskRegion_A_DISKACCESSEXCEPTION_HAS_OCCURED_WHILE_RECOVERING_FROM_DISK =
+  public static final StringId PlaceHolderDiskRegion_A_DISKACCESSEXCEPTION_HAS_OCCURRED_WHILE_RECOVERING_FROM_DISK =
       new StringId(5092,
           "A DiskAccessException has occurred while recovering values asynchronously from disk for region {0}.");
   public static final StringId PartitionedRegion_FOR_REGION_0_TotalBucketNum_1_SHOULD_NOT_BE_CHANGED_Previous_Configured_2 =
@@ -6876,7 +6876,7 @@ public class LocalizedStrings {
   public static final StringId BucketPersistenceAdvisor_ERROR_RECOVERYING_SECONDARY_BUCKET_0 =
       new StringId(5137, "Unable to recover secondary bucket from disk for region {0} bucket {1}");
   public static final StringId FunctionService_EXCEPTION_ON_LOCAL_NODE =
-      new StringId(5138, "Exception occured on local node while executing Function:");
+      new StringId(5138, "Exception occurred on local node while executing Function:");
   public static final StringId AbstractIndex_WRONG_COMPARETO_IMPLEMENTATION_IN_INDEXED_OBJECT_0 =
       new StringId(5139, "Indexed object''s class {0} compareTo function is errorneous.");
   public static final StringId DefaultQuery_API_ONLY_FOR_PR =
@@ -7207,9 +7207,9 @@ public class LocalizedStrings {
   public static final StringId Region_REGION_0_HAS_1_ASYNC_EVENT_QUEUE_IDS_ANOTHER_CACHE_HAS_THE_SAME_REGION_WITH_2_ASYNC_EVENT_QUEUE_IDS_FOR_REGION_ACROSS_ALL_MEMBERS_IN_DS_ASYNC_EVENT_QUEUE_IDS_SHOULD_BE_SAME =
       new StringId(5304,
           "Region {0} has {1} AsyncEvent queue IDs. Another cache has same region with {2} AsyncEvent queue IDs. For region across all members, AsyncEvent queue IDs should be same.");
-  public static final StringId GatewayEventFilter_EXCEPTION_OCCURED_WHILE_HANDLING_CALL_TO_0_AFTER_ACKNOWLEDGEMENT_FOR_EVENT_1 =
+  public static final StringId GatewayEventFilter_EXCEPTION_OCCURRED_WHILE_HANDLING_CALL_TO_0_AFTER_ACKNOWLEDGEMENT_FOR_EVENT_1 =
       new StringId(5305,
-          "Exception occured while handling call to {0}.afterAcknowledgement for event {1}:");
+          "Exception occurred while handling call to {0}.afterAcknowledgement for event {1}:");
   public static final StringId GatewayReceiverImpl_USING_LOCAL_HOST =
       new StringId(5399, "No bind-address or hostname-for-sender is specified, Using local host ");
   public static final StringId GatewayReceiverImpl_COULD_NOT_GET_HOST_NAME =
@@ -7376,13 +7376,13 @@ public class LocalizedStrings {
           "enforce-unique-host and redundancy-zone properties have no effect for a LonerDistributedSystem.");
   public static final StringId AttributesFactory_UNABLE_TO_CREATE_DISK_STORE_DIRECTORY_0 =
       new StringId(5607, "Unable to create directory : {0}");
-  public static final StringId LocalRegion_A_DISKACCESSEXCEPTION_HAS_OCCURED_WHILE_WRITING_TO_THE_DISK_FOR_REGION_0_THE_CACHE_WILL_BE_CLOSED =
+  public static final StringId LocalRegion_A_DISKACCESSEXCEPTION_HAS_OCCURRED_WHILE_WRITING_TO_THE_DISK_FOR_REGION_0_THE_CACHE_WILL_BE_CLOSED =
       new StringId(5608,
           "A DiskAccessException has occurred while writing to the disk for region {0}. The cache will be closed.");
-  public static final StringId LocalRegion_A_DISKACCESSEXCEPTION_HAS_OCCURED_WHILE_WRITING_TO_THE_DISK_FOR_DISKSTORE_0_THE_CACHE_WILL_BE_CLOSED =
+  public static final StringId LocalRegion_A_DISKACCESSEXCEPTION_HAS_OCCURRED_WHILE_WRITING_TO_THE_DISK_FOR_DISKSTORE_0_THE_CACHE_WILL_BE_CLOSED =
       new StringId(5609,
           "A DiskAccessException has occurred while writing to the disk for disk store {0}. The cache will be closed.");
-  public static final StringId LocalRegion_AN_EXCEPTION_OCCURED_WHILE_CLOSING_THE_CACHE =
+  public static final StringId LocalRegion_AN_EXCEPTION_OCCURRED_WHILE_CLOSING_THE_CACHE =
       new StringId(5610, "An Exception occurred while closing the cache.");
 
   public static final StringId DiskWriteAttributesFactory_DISK_USAGE_WARNING_INVALID_0 =
@@ -7480,7 +7480,7 @@ public class LocalizedStrings {
   public static final StringId Gateway_OBSOLETE_SYSTEM_POPERTY = new StringId(5711,
       "Obsolete java system property named {0} was set to control {1}. This property is no longer supported. Please use the GemFire API instead.");
   public static final StringId GatewayReceiver_EXCEPTION_WHILE_STARTING_GATEWAY_RECEIVER =
-      new StringId(5712, "Exception occured while starting gateway receiver");
+      new StringId(5712, "Exception occurred while starting gateway receiver");
   public static final StringId GatewayReceiver_IS_NOT_RUNNING =
       new StringId(5713, "Gateway Receiver is not running");
   public static final StringId GatewayReceiver_IS_ALREADY_RUNNING =

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/internal/jta/GlobalTransaction.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/internal/jta/GlobalTransaction.java b/geode-core/src/main/java/org/apache/geode/internal/jta/GlobalTransaction.java
index b0c548e..03eeb20 100644
--- a/geode-core/src/main/java/org/apache/geode/internal/jta/GlobalTransaction.java
+++ b/geode-core/src/main/java/org/apache/geode/internal/jta/GlobalTransaction.java
@@ -358,7 +358,7 @@ public class GlobalTransaction {
             }
           } catch (XAException xe) {
             String exception =
-                LocalizedStrings.GlobalTransaction_GLOBALTRANSACTION_ENLISTRESOURCE_EXCEPTION_OCCURED_IN_TRYING_TO_SET_XARESOURCE_TIMEOUT_DUE_TO_0_ERROR_CODE_1
+                LocalizedStrings.GlobalTransaction_GLOBALTRANSACTION_ENLISTRESOURCE_EXCEPTION_OCCURRED_IN_TRYING_TO_SET_XARESOURCE_TIMEOUT_DUE_TO_0_ERROR_CODE_1
                     .toLocalizedString(new Object[] {xe, Integer.valueOf(xe.errorCode)});
             LogWriterI18n writer = TransactionUtils.getLogWriterI18n();
             if (VERBOSE)
@@ -601,7 +601,7 @@ public class GlobalTransaction {
     } catch (Exception e) {
       if (writer.severeEnabled())
         writer.severe(
-            LocalizedStrings.GlobalTransaction_GLOBATRANSACTION_EXPIREGTX_ERROR_OCCURED_WHILE_REMOVING_TRANSACTIONAL_MAPPINGS_0,
+            LocalizedStrings.GlobalTransaction_GLOBATRANSACTION_EXPIREGTX_ERROR_OCCURRED_WHILE_REMOVING_TRANSACTIONAL_MAPPINGS_0,
             e, e);
     }
   }
@@ -628,7 +628,7 @@ public class GlobalTransaction {
             resetXATimeOut = xar.setTransactionTimeout(seconds);
           } catch (XAException e) {
             String exception =
-                LocalizedStrings.GlobalTransaction_EXCEPTION_OCCURED_WHILE_TRYING_TO_SET_THE_XARESOURCE_TIMEOUT_DUE_TO_0_ERROR_CODE_1
+                LocalizedStrings.GlobalTransaction_EXCEPTION_OCCURRED_WHILE_TRYING_TO_SET_THE_XARESOURCE_TIMEOUT_DUE_TO_0_ERROR_CODE_1
                     .toLocalizedString(new Object[] {e, Integer.valueOf(e.errorCode)});
             LogWriterI18n writer = TransactionUtils.getLogWriterI18n();
             if (VERBOSE)

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/internal/logging/LoggingThreadGroup.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/internal/logging/LoggingThreadGroup.java b/geode-core/src/main/java/org/apache/geode/internal/logging/LoggingThreadGroup.java
index 7bb2d93..ee61dc3 100755
--- a/geode-core/src/main/java/org/apache/geode/internal/logging/LoggingThreadGroup.java
+++ b/geode-core/src/main/java/org/apache/geode/internal/logging/LoggingThreadGroup.java
@@ -267,7 +267,7 @@ public class LoggingThreadGroup extends ThreadGroup {
       if ((ex instanceof NoClassDefFoundError)
           && (threadName.equals(InternalDistributedSystem.SHUTDOWN_HOOK_NAME))) {
         final StringId msg =
-            LocalizedStrings.UNCAUGHT_EXCEPTION_IN_THREAD_0_THIS_MESSAGE_CAN_BE_DISREGARDED_IF_IT_OCCURED_DURING_AN_APPLICATION_SERVER_SHUTDOWN_THE_EXCEPTION_MESSAGE_WAS_1;
+            LocalizedStrings.UNCAUGHT_EXCEPTION_IN_THREAD_0_THIS_MESSAGE_CAN_BE_DISREGARDED_IF_IT_OCCURRED_DURING_AN_APPLICATION_SERVER_SHUTDOWN_THE_EXCEPTION_MESSAGE_WAS_1;
         final Object[] msgArgs = new Object[] {t, ex.getLocalizedMessage()};
         stderr.info(msg, msgArgs);
         if (this.logger != null) {

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/internal/tcp/MsgDestreamer.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/internal/tcp/MsgDestreamer.java b/geode-core/src/main/java/org/apache/geode/internal/tcp/MsgDestreamer.java
index 860d55b..e85046c 100644
--- a/geode-core/src/main/java/org/apache/geode/internal/tcp/MsgDestreamer.java
+++ b/geode-core/src/main/java/org/apache/geode/internal/tcp/MsgDestreamer.java
@@ -168,7 +168,7 @@ public class MsgDestreamer {
   /**
    * Waits for the deserialization to complete and returns the deserialized message.
    * 
-   * @throws IOException A problem occured while deserializing the message.
+   * @throws IOException A problem occurred while deserializing the message.
    * @throws ClassNotFoundException The class of an object read from <code>in</code> could not be
    *         found
    */

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/management/JVMMetrics.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/management/JVMMetrics.java b/geode-core/src/main/java/org/apache/geode/management/JVMMetrics.java
index 388c8f6..b15aff7 100644
--- a/geode-core/src/main/java/org/apache/geode/management/JVMMetrics.java
+++ b/geode-core/src/main/java/org/apache/geode/management/JVMMetrics.java
@@ -81,7 +81,7 @@ public class JVMMetrics implements Serializable {
   }
 
   /**
-   * Returns the number of times garbage collection has occured.
+   * Returns the number of times garbage collection has occurred.
    */
   public long getGcCount() {
     return gcCount;

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/management/internal/beans/stats/StatsKey.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/management/internal/beans/stats/StatsKey.java b/geode-core/src/main/java/org/apache/geode/management/internal/beans/stats/StatsKey.java
index 32ce55b..aaedc71 100644
--- a/geode-core/src/main/java/org/apache/geode/management/internal/beans/stats/StatsKey.java
+++ b/geode-core/src/main/java/org/apache/geode/management/internal/beans/stats/StatsKey.java
@@ -291,7 +291,7 @@ public class StatsKey {
   public static final String UPDATE_REQUESTS = "updateRequest";
   public static final String DESTROY_REQUESTS = "destroyRequest";
   public static final String UNKNOWN_OPERATIONS_RECEIVED = "unknowsOperationsReceived";
-  public static final String EXCEPTIONS_OCCURED = "exceptionsOccured";
+  public static final String EXCEPTIONS_OCCURRED = "exceptionsOccurred";
   public static final String BATCH_PROCESS_TIME = "processBatchTime";
   public static final String TOTAL_BATCHES = "processBatchRequests";
 

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/management/internal/cli/commands/ShellCommands.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/management/internal/cli/commands/ShellCommands.java b/geode-core/src/main/java/org/apache/geode/management/internal/cli/commands/ShellCommands.java
index ff3b29f..81a96ae 100644
--- a/geode-core/src/main/java/org/apache/geode/management/internal/cli/commands/ShellCommands.java
+++ b/geode-core/src/main/java/org/apache/geode/management/internal/cli/commands/ShellCommands.java
@@ -963,7 +963,7 @@ public class ShellCommands implements CommandMarker {
     } catch (Exception e) {
       LogWrapper.getInstance().info(CliUtil.stackTraceAsString(e));
       return ResultBuilder
-          .createGemFireErrorResult("Exception occured while clearing history " + e.getMessage());
+          .createGemFireErrorResult("Exception occurred while clearing history " + e.getMessage());
     }
     return ResultBuilder.createInfoResult(CliStrings.HISTORY__MSG__CLEARED_HISTORY);
 

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/management/internal/cli/i18n/CliStrings.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/management/internal/cli/i18n/CliStrings.java b/geode-core/src/main/java/org/apache/geode/management/internal/cli/i18n/CliStrings.java
index 25398a1..68d055c 100644
--- a/geode-core/src/main/java/org/apache/geode/management/internal/cli/i18n/CliStrings.java
+++ b/geode-core/src/main/java/org/apache/geode/management/internal/cli/i18n/CliStrings.java
@@ -742,7 +742,7 @@ public class CliStrings {
   public static final String CREATE_INDEX__FAILURE__MSG =
       "Failed to create index \"{0}\" due to following reasons";
   public static final String CREATE_INDEX__ERROR__MSG =
-      "Exception \"{0}\" occured on following members";
+      "Exception \"{0}\" occurred on following members";
   public static final String CREATE_INDEX__NAME__CONFLICT =
       "Index \"{0}\" already exists.  " + "Create failed due to duplicate name.";
   public static final String CREATE_INDEX__INDEX__EXISTS =
@@ -1324,7 +1324,7 @@ public class CliStrings {
   public static final String EXECUTE_FUNCTION__MSG__DOES_NOT_HAVE_FUNCTION_0_REGISTERED =
       "Function : {0} is not registered on member.";
   public static final String EXECUTE_FUNCTION__MSG__ERROR_IN_EXECUTING_ON_MEMBER_1_DETAILS_2 =
-      "While executing function : {0} on member : {1} error occured : {2}";
+      "While executing function : {0} on member : {1} error occurred : {2}";
   public static final String EXECUTE_FUNCTION__MSG__RESULT_COLLECTOR_0_NOT_FOUND_ERROR_1 =
       "ResultCollector : {0} not found. Error : {1}";
   public static final String EXECUTE_FUNCTION__MSG__MXBEAN_0_FOR_NOT_FOUND =
@@ -1334,7 +1334,7 @@ public class CliStrings {
   public static final String EXECUTE_FUNCTION__MSG__DS_HAS_NO_MEMBERS =
       "Distributed system has no members";
   public static final String EXECUTE_FUNCTION__MSG__ERROR_IN_EXECUTING_0_ON_REGION_1_DETAILS_2 =
-      "While executing function : {0} on region : {1} error occured : {2}";
+      "While executing function : {0} on region : {1} error occurred : {2}";
   public static final String EXECUTE_FUNCTION__MSG__ERROR_IN_RETRIEVING_EXECUTOR =
       "Could not retrieve executor";
   public static final String EXECUTE_FUNCTION__MSG__GROUPS_0_HAS_NO_MEMBERS =
@@ -1344,7 +1344,7 @@ public class CliStrings {
   public static final String EXECUTE_FUNCTION__MSG__COULD_NOT_RETRIEVE_ARGUMENTS =
       "Could not retrieve arguments";
   public static final String EXECUTE_FUNCTION__MSG__ERROR_IN_EXECUTING_0_ON_MEMBER_1_ON_REGION_2_DETAILS_3 =
-      "While executing function : {0} on member : {1} one region : {2} error occured : {3}";
+      "While executing function : {0} on member : {1} one region : {2} error occurred : {3}";
   public static final String EXECUTE_FUNCTION__MSG__MEMBER_SHOULD_NOT_HAVE_FILTER_FOR_EXECUTION =
       "Filters for executing on \"member\"/\"mebers of group\" is not supported.";
 
@@ -1467,9 +1467,9 @@ public class CliStrings {
       "Abort the command if already exists at locator directory";
   public static final String EXPORT_STACKTRACE__MEMBER__NOT__FOUND = "Member not found";
   public static final String EXPORT_STACKTRACE__SUCCESS = "stack-trace(s) exported to file: {0}";
-  public static final String EXPORT_STACKTRACE__ERROR = "Error occured while showing stack-traces";
+  public static final String EXPORT_STACKTRACE__ERROR = "Error occurred while showing stack-traces";
   public static final String EXPORT_STACKTRACE__ERROR__FILE__PRESENT =
-      "Error occured while exporting stack-traces, file {0} already present";
+      "Error occurred while exporting stack-traces, file {0} already present";
   public static final String EXPORT_STACKTRACE__HOST = "On host : ";
   public static final String EXPORT_STACKTRACE_WARN_USER =
       "If file {0} already present at locator directory it will be overwritten, do you want to continue?";
@@ -1620,7 +1620,7 @@ public class CliStrings {
   public static final String DESCRIBE_CLIENT_COULD_NOT_RETRIEVE_STATS_FOR_CLIENT_0_REASON_1 =
       "Could not retrieve stats for client : {0}. Reason : {1}";
   public static final String DESCRIBE_CLIENT_ERROR_FETCHING_STATS_0 =
-      "Error occured while fetching stats. Reason : {0}";
+      "Error occurred while fetching stats. Reason : {0}";
   public static final String DESCRIBE_CLIENT_NO_MEMBERS = "DS has no members";
   public static final String DESCRIBE_CLIENT_COLUMN_PRIMARY_SERVERS = "Primary Servers";
   public static final String DESCRIBE_CLIENT_COLUMN_SECONDARY_SERVERS = "Secondary Servers";
@@ -1890,9 +1890,9 @@ public class CliStrings {
   public static final String REBALANCE__MSG__NO_REBALANCING_REGIONS_ON_DS =
       "Distributed system has no regions that can be rebalanced";
   public static final String REBALANCE__MSG__EXCEPTION_IN_REBALANCE_FOR_MEMBER_0_Exception =
-      "Excpetion occured while rebalancing on member : {0} . Exception is ";
+      "Excpetion occurred while rebalancing on member : {0} . Exception is ";
   public static final String REBALANCE__MSG__EXCEPTION_IN_REBALANCE_FOR_MEMBER_0_Exception_1 =
-      "Excpetion occured while rebalancing on member : {0} . Exception is : {1}";
+      "Excpetion occurred while rebalancing on member : {0} . Exception is : {1}";
   public static final String REBALANCE__MSG__ERROR_IN_RETRIEVING_MBEAN =
       "Could not retrieve MBean for region : {0}";
   public static final String REBALANCE__MSG__NO_EXECUTION_FOR_REGION_0_ON_MEMBERS_1 =
@@ -1907,7 +1907,7 @@ public class CliStrings {
   public static final String REBALANCE__MSG__REGION_NOT_ASSOCIATED_WITH_MORE_THAN_ONE_MEMBER =
       "No regions associated with more than 1 members";
   public static final String REBALANCE__MSG__EXCEPTION_OCCRED_WHILE_REBALANCING_0 =
-      "Exception occured while rebelancing. Reason : {0}";
+      "Exception occurred while rebelancing. Reason : {0}";
 
   /* remove command */
   public static final String REMOVE = "remove";
@@ -2089,7 +2089,7 @@ public class CliStrings {
       "To shutdown locators specify this option as true. Default is false";
   public static final String SHUTDOWN__MSG__CANNOT_EXECUTE = "Cannot execute";
   public static final String SHUTDOWN__MSG__ERROR =
-      "Exception occured while shutdown. Reason : {0}";
+      "Exception occurred while shutdown. Reason : {0}";
   public static final String SHUTDOWN__MSG__MANAGER_NOT_FOUND = "Could not locate Manager.";
   public static final String SHUTDOWN__MSG__WARN_USER =
       "As a lot of data in memory will be lost, including possibly events in queues, do you really want to shutdown the entire distributed system?";
@@ -2870,7 +2870,7 @@ public class CliStrings {
   public static final String UPGRADE_OFFLINE_DISK_STORE__MSG__CANNOT_ACCESS_DISKSTORE_0_FROM_1_CHECK_GFSH_LOGS =
       COMPACT_OFFLINE_DISK_STORE__MSG__CANNOT_ACCESS_DISKSTORE_0_FROM_1_CHECK_GFSH_LOGS;
   public static final String UPGRADE_OFFLINE_DISK_STORE__MSG__ERROR_WHILE_COMPACTING_DISKSTORE_0_WITH_1_REASON_2 =
-      "Error occured while upgrading disk store={0} {1}. Reason: {2}";
+      "Error occurred while upgrading disk store={0} {1}. Reason: {2}";
 
   /* 'validate disk-store' command */
   public static final String VALIDATE_DISK_STORE = "validate offline-disk-store";

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/batterytest/greplogs/ExpectedStrings.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/batterytest/greplogs/ExpectedStrings.java b/geode-core/src/test/java/batterytest/greplogs/ExpectedStrings.java
index c598b7a..2b8a8b9 100644
--- a/geode-core/src/test/java/batterytest/greplogs/ExpectedStrings.java
+++ b/geode-core/src/test/java/batterytest/greplogs/ExpectedStrings.java
@@ -113,7 +113,7 @@ public class ExpectedStrings {
       expected.add(Pattern.compile("SQLException: Database 'newDB1' not found"));
       expected.add(Pattern.compile("IGNORE_EXCEPTION_test"));
       expected.add(Pattern.compile("Unsupported at this time"));
-      expected.add(Pattern.compile("DiskAccessException occured as expected"));
+      expected.add(Pattern.compile("DiskAccessException occurred as expected"));
       expected.add(Pattern.compile("Oplog::createOplog:Exception in preblowing the file"));
     } else if (type.equals("dunit")) {
       expected.add(Pattern.compile("INCOMPATIBLE_ROOT"));

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/JtaNoninvolvementJUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/org/apache/geode/JtaNoninvolvementJUnitTest.java b/geode-core/src/test/java/org/apache/geode/JtaNoninvolvementJUnitTest.java
index fc52fd8..75601d6 100644
--- a/geode-core/src/test/java/org/apache/geode/JtaNoninvolvementJUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/JtaNoninvolvementJUnitTest.java
@@ -119,7 +119,7 @@ public class JtaNoninvolvementJUnitTest {
         createCache(false);
       }
       final CountDownLatch l = new CountDownLatch(1);
-      final AtomicBoolean exceptionOccured = new AtomicBoolean(false);
+      final AtomicBoolean exceptionOccurred = new AtomicBoolean(false);
       ut = (UserTransaction) cache.getJNDIContext().lookup("java:/UserTransaction");
       ut.begin();
       txRegion.put("key", "value");
@@ -128,17 +128,17 @@ public class JtaNoninvolvementJUnitTest {
         @Override
         public void run() {
           if (txRegion.get("key") != null) {
-            exceptionOccured.set(true);
+            exceptionOccurred.set(true);
           }
           if (nonTxRegion.get("key") != null) {
-            exceptionOccured.set(true);
+            exceptionOccurred.set(true);
           }
           l.countDown();
         }
       });
       t.start();
       l.await();
-      assertFalse(exceptionOccured.get());
+      assertFalse(exceptionOccurred.get());
     } finally {
       if (ut != null) {
         ut.commit();

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/cache/ConnectionPoolDUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/org/apache/geode/cache/ConnectionPoolDUnitTest.java b/geode-core/src/test/java/org/apache/geode/cache/ConnectionPoolDUnitTest.java
index 2d5a71b..c3e756b 100755
--- a/geode-core/src/test/java/org/apache/geode/cache/ConnectionPoolDUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/cache/ConnectionPoolDUnitTest.java
@@ -792,10 +792,10 @@ public class ConnectionPoolDUnitTest extends JUnit4CacheTestCase {
     ThreadUtils.join(inv3, 30 * 1000);
 
     if (inv2.exceptionOccurred()) {
-      org.apache.geode.test.dunit.Assert.fail("Error occured in vm2", inv2.getException());
+      org.apache.geode.test.dunit.Assert.fail("Error occurred in vm2", inv2.getException());
     }
     if (inv3.exceptionOccurred()) {
-      org.apache.geode.test.dunit.Assert.fail("Error occured in vm3", inv3.getException());
+      org.apache.geode.test.dunit.Assert.fail("Error occurred in vm3", inv3.getException());
     }
   }
 

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/cache/partition/PartitionRegionHelperDUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/org/apache/geode/cache/partition/PartitionRegionHelperDUnitTest.java b/geode-core/src/test/java/org/apache/geode/cache/partition/PartitionRegionHelperDUnitTest.java
index 4236799..dd75d67 100644
--- a/geode-core/src/test/java/org/apache/geode/cache/partition/PartitionRegionHelperDUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/cache/partition/PartitionRegionHelperDUnitTest.java
@@ -260,7 +260,7 @@ public class PartitionRegionHelperDUnitTest extends JUnit4CacheTestCase {
           try {
             date = sdf.parse(dateString);
           } catch (ParseException e) {
-            Assert.fail("Exception Occured while parseing date", e);
+            Assert.fail("Exception Occurred while parseing date", e);
           }
           String value = month.toString() + 10;
           region.put(date, value);
@@ -281,7 +281,7 @@ public class PartitionRegionHelperDUnitTest extends JUnit4CacheTestCase {
           try {
             date = sdf.parse(dateString);
           } catch (ParseException e) {
-            Assert.fail("Exception Occured while parseing date", e);
+            Assert.fail("Exception Occurred while parseing date", e);
           }
           DistributedMember key1Pri = PartitionRegionHelper.getPrimaryMemberForKey(region, date);
           assertNotNull(key1Pri);

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/cache/query/QueryJUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/org/apache/geode/cache/query/QueryJUnitTest.java b/geode-core/src/test/java/org/apache/geode/cache/query/QueryJUnitTest.java
index f08eef5..36d5144 100644
--- a/geode-core/src/test/java/org/apache/geode/cache/query/QueryJUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/cache/query/QueryJUnitTest.java
@@ -373,7 +373,7 @@ public class QueryJUnitTest {
       try {
         q.execute(params);
       } catch (Exception e) {
-        throw new AssertionError("exception occured while executing query", e);
+        throw new AssertionError("exception occurred while executing query", e);
       }
     }
   }

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/cache/query/functional/IndexCreationJUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/org/apache/geode/cache/query/functional/IndexCreationJUnitTest.java b/geode-core/src/test/java/org/apache/geode/cache/query/functional/IndexCreationJUnitTest.java
index 620ab17..3c64465 100755
--- a/geode-core/src/test/java/org/apache/geode/cache/query/functional/IndexCreationJUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/cache/query/functional/IndexCreationJUnitTest.java
@@ -176,7 +176,7 @@ public class IndexCreationJUnitTest {
     // Task ID: ICM17
     QueryService qs;
     qs = CacheUtils.getQueryService();
-    // boolean exceptionoccured = true;
+    // boolean exceptionoccurred = true;
     qs.createIndex("statusIndex", IndexType.FUNCTIONAL, "status", "/portfolios, positions");
     qs.createIndex("secIdIndex", IndexType.FUNCTIONAL, "b.secId",
         "/portfolios pf, pf.positions.values b");

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/cache/query/functional/MiscJUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/org/apache/geode/cache/query/functional/MiscJUnitTest.java b/geode-core/src/test/java/org/apache/geode/cache/query/functional/MiscJUnitTest.java
index 0555b7e..b9f69d7 100644
--- a/geode-core/src/test/java/org/apache/geode/cache/query/functional/MiscJUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/cache/query/functional/MiscJUnitTest.java
@@ -397,7 +397,7 @@ public class MiscJUnitTest {
       rgn.put("name" + i, pf);
     }
     final Object lock = new Object();
-    final boolean[] expectionOccured = new boolean[] {false};
+    final boolean[] expectionOccurred = new boolean[] {false};
     final boolean[] keepGoing = new boolean[] {true};
 
     Thread indexCreatorDestroyer = new Thread(new Runnable() {
@@ -429,7 +429,7 @@ public class MiscJUnitTest {
             region.getCache().getLogger().error(e);
             e.printStackTrace();
             synchronized (lock) {
-              expectionOccured[0] = true;
+              expectionOccurred[0] = true;
               keepGoing[0] = false;
               continueRunning = false;
             }
@@ -459,7 +459,7 @@ public class MiscJUnitTest {
               e.printStackTrace();
               region.getCache().getLogger().error(e);
               synchronized (lock) {
-                expectionOccured[0] = true;
+                expectionOccurred[0] = true;
                 keepGoing[0] = false;
                 continueRunning = false;
               }
@@ -470,7 +470,7 @@ public class MiscJUnitTest {
       });
     }
     synchronized (lock) {
-      assertFalse(expectionOccured[0]);
+      assertFalse(expectionOccurred[0]);
     }
 
     for (int i = 0; i < THREAD_COUNT; ++i) {
@@ -486,7 +486,7 @@ public class MiscJUnitTest {
 
     indexCreatorDestroyer.join();
     synchronized (lock) {
-      assertFalse(expectionOccured[0]);
+      assertFalse(expectionOccurred[0]);
     }
 
   }

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/cache/query/internal/IndexManagerJUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/org/apache/geode/cache/query/internal/IndexManagerJUnitTest.java b/geode-core/src/test/java/org/apache/geode/cache/query/internal/IndexManagerJUnitTest.java
index 929bd46..3f40c97 100644
--- a/geode-core/src/test/java/org/apache/geode/cache/query/internal/IndexManagerJUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/cache/query/internal/IndexManagerJUnitTest.java
@@ -91,7 +91,7 @@ public class IndexManagerJUnitTest {
     assertFalse(IndexManager.setIndexBufferTime(0, 9));
     assertFalse(IndexManager.setIndexBufferTime(1, 10));
 
-    // Now let's assume a new update has occured where the time is larger (enough to roll off the
+    // Now let's assume a new update has occurred where the time is larger (enough to roll off the
     // large delta)
     // but the delta is smaller
     assertTrue(IndexManager.setIndexBufferTime(30, 30));

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/cache/query/internal/index/AsynchIndexMaintenanceJUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/org/apache/geode/cache/query/internal/index/AsynchIndexMaintenanceJUnitTest.java b/geode-core/src/test/java/org/apache/geode/cache/query/internal/index/AsynchIndexMaintenanceJUnitTest.java
index 3d3df43..6ce9268 100644
--- a/geode-core/src/test/java/org/apache/geode/cache/query/internal/index/AsynchIndexMaintenanceJUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/cache/query/internal/index/AsynchIndexMaintenanceJUnitTest.java
@@ -49,7 +49,7 @@ public class AsynchIndexMaintenanceJUnitTest {
   private Region region;
 
   private boolean indexUsed = false;
-  private volatile boolean exceptionOccured = false;
+  private volatile boolean exceptionOccurred = false;
 
   private Set idSet;
 
@@ -233,7 +233,7 @@ public class AsynchIndexMaintenanceJUnitTest {
             }
           } catch (Exception e) {
             CacheUtils.getLogger().error(e);
-            exceptionOccured = true;
+            exceptionOccurred = true;
           }
         }
       });
@@ -247,9 +247,9 @@ public class AsynchIndexMaintenanceJUnitTest {
       }
     } catch (Exception e) {
       CacheUtils.getLogger().error(e);
-      exceptionOccured = true;
+      exceptionOccurred = true;
     }
-    assertFalse(exceptionOccured);
+    assertFalse(exceptionOccurred);
   }
 
 }

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/cache/query/internal/index/HashIndexSetJUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/org/apache/geode/cache/query/internal/index/HashIndexSetJUnitTest.java b/geode-core/src/test/java/org/apache/geode/cache/query/internal/index/HashIndexSetJUnitTest.java
index 20fc1e1..e08baf1 100644
--- a/geode-core/src/test/java/org/apache/geode/cache/query/internal/index/HashIndexSetJUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/cache/query/internal/index/HashIndexSetJUnitTest.java
@@ -139,7 +139,7 @@ public class HashIndexSetJUnitTest {
     his.hashIndexSetProperties.removedTokens = his.hashIndexSetProperties.maxSize;
     addPortfoliosToHashIndexSet(portfoliosMap, his);
 
-    // compaction should have occured, removed tokens should now be gone
+    // compaction should have occurred, removed tokens should now be gone
     assertEquals(0, his.hashIndexSetProperties.removedTokens);
     assertEquals(numEntries, his.size());
   }

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/cache/query/partitioned/PRQueryCacheClosedJUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/org/apache/geode/cache/query/partitioned/PRQueryCacheClosedJUnitTest.java b/geode-core/src/test/java/org/apache/geode/cache/query/partitioned/PRQueryCacheClosedJUnitTest.java
index a7c1b9b..d1b41b8 100755
--- a/geode-core/src/test/java/org/apache/geode/cache/query/partitioned/PRQueryCacheClosedJUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/cache/query/partitioned/PRQueryCacheClosedJUnitTest.java
@@ -212,10 +212,10 @@ public class PRQueryCacheClosedJUnitTest {
       ThreadUtils.join(t1, 30 * 1000);
       ThreadUtils.join(t2, 30 * 1000);
       logger.info(
-          "PRQueryCacheClosedJUnitTest#testQueryOnSingleDataStoreWithCacheClose: checking for any Unexpected Exception's occured");
+          "PRQueryCacheClosedJUnitTest#testQueryOnSingleDataStoreWithCacheClose: checking for any Unexpected Exception's occurred");
 
       assertFalse(
-          "PRQueryCacheClosedJUnitTest#testQueryOnSingleDataStoreWithCacheClose: Exception occured in Query-thread: "
+          "PRQueryCacheClosedJUnitTest#testQueryOnSingleDataStoreWithCacheClose: Exception occurred in Query-thread: "
               + errorBuf,
           encounteredException);
     } catch (Exception e) {

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/cache/query/partitioned/PRQueryRegionClosedJUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/org/apache/geode/cache/query/partitioned/PRQueryRegionClosedJUnitTest.java b/geode-core/src/test/java/org/apache/geode/cache/query/partitioned/PRQueryRegionClosedJUnitTest.java
index 94718e0..2bf064c 100755
--- a/geode-core/src/test/java/org/apache/geode/cache/query/partitioned/PRQueryRegionClosedJUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/cache/query/partitioned/PRQueryRegionClosedJUnitTest.java
@@ -204,10 +204,10 @@ public class PRQueryRegionClosedJUnitTest {
       t2.join(30000);
       assertFalse(t2.isAlive());
       logger.info(
-          "PRQueryRegionClosedJUnitTest#testQueryingWithRegionClose: checking for any Unexpected Exception's occured");
+          "PRQueryRegionClosedJUnitTest#testQueryingWithRegionClose: checking for any Unexpected Exception's occurred");
 
       assertFalse(
-          "PRQueryRegionClosedJUnitTest#testQueryingWithRegionClose: Exception occured in Query-thread",
+          "PRQueryRegionClosedJUnitTest#testQueryingWithRegionClose: Exception occurred in Query-thread",
           encounteredException);
     } catch (Exception e) {
       e.printStackTrace();

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/cache/query/partitioned/PRQueryRegionDestroyedJUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/org/apache/geode/cache/query/partitioned/PRQueryRegionDestroyedJUnitTest.java b/geode-core/src/test/java/org/apache/geode/cache/query/partitioned/PRQueryRegionDestroyedJUnitTest.java
index 4ddf27c..a9fffd1 100755
--- a/geode-core/src/test/java/org/apache/geode/cache/query/partitioned/PRQueryRegionDestroyedJUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/cache/query/partitioned/PRQueryRegionDestroyedJUnitTest.java
@@ -202,10 +202,10 @@ public class PRQueryRegionDestroyedJUnitTest {
       ThreadUtils.join(t1, 30 * 1000);
       ThreadUtils.join(t2, 30 * 1000);
       logger.info(
-          "PRQueryRegionDestroyedJUnitTest#testQueryOnSingleDataStore: checking for any Unexpected Exception's occured");
+          "PRQueryRegionDestroyedJUnitTest#testQueryOnSingleDataStore: checking for any Unexpected Exception's occurred");
 
       assertFalse(
-          "PRQueryRegionDestroyedJUnitTest#testQueryOnSingleDataStore: Exception occured in Query-thread",
+          "PRQueryRegionDestroyedJUnitTest#testQueryOnSingleDataStore: Exception occurred in Query-thread",
           encounteredException);
     } catch (Exception e) {
       e.printStackTrace();

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/cache30/DiskRegionDUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/org/apache/geode/cache30/DiskRegionDUnitTest.java b/geode-core/src/test/java/org/apache/geode/cache30/DiskRegionDUnitTest.java
index 8b0fecd..e5d3fbd 100644
--- a/geode-core/src/test/java/org/apache/geode/cache30/DiskRegionDUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/cache30/DiskRegionDUnitTest.java
@@ -641,7 +641,7 @@ public class DiskRegionDUnitTest extends JUnit4CacheTestCase {
             fail("The values should have been evicted to disk, for key: " + "Key-" + i);
           }
         } catch (EntryNotFoundException e) {
-          fail("Entry not found not expected but occured ");
+          fail("Entry not found not expected but occurred ");
         }
       }
     }

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/internal/cache/Bug37377DUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/org/apache/geode/internal/cache/Bug37377DUnitTest.java b/geode-core/src/test/java/org/apache/geode/internal/cache/Bug37377DUnitTest.java
index 45498eb..3d0be6a 100644
--- a/geode-core/src/test/java/org/apache/geode/internal/cache/Bug37377DUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/internal/cache/Bug37377DUnitTest.java
@@ -63,7 +63,7 @@ public class Bug37377DUnitTest extends JUnit4CacheTestCase {
 
   transient private static CountDownLatch clearLatch = new CountDownLatch(1);
 
-  static Boolean clearOccured = false;
+  static Boolean clearOccurred = false;
 
   public Bug37377DUnitTest() {
     super();
@@ -291,11 +291,11 @@ public class Bug37377DUnitTest extends JUnit4CacheTestCase {
     public boolean initialImageInit(final LocalRegion r, final long lastModifiedTime,
         final Object newValue, final boolean create, final boolean wasRecovered,
         final boolean versionTagAccepted) throws RegionClearedException {
-      synchronized (clearOccured) {
-        if (!clearOccured) {
+      synchronized (clearOccurred) {
+        if (!clearOccurred) {
           // Force other member to perform a clear during our GII
           invokeRemoteClearAndWait(otherVM, thisVM);
-          clearOccured = true;
+          clearOccurred = true;
         }
       }
 

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/internal/cache/ConcurrentFlushingAndRegionOperationsJUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/org/apache/geode/internal/cache/ConcurrentFlushingAndRegionOperationsJUnitTest.java b/geode-core/src/test/java/org/apache/geode/internal/cache/ConcurrentFlushingAndRegionOperationsJUnitTest.java
index dec404a..7b816d1 100755
--- a/geode-core/src/test/java/org/apache/geode/internal/cache/ConcurrentFlushingAndRegionOperationsJUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/internal/cache/ConcurrentFlushingAndRegionOperationsJUnitTest.java
@@ -61,7 +61,7 @@ public class ConcurrentFlushingAndRegionOperationsJUnitTest extends DiskRegionTe
       assertEquals("Value2", region.get("Key"));
       assertEquals("Value2", getValueOnDisk(region));
     } catch (EntryNotFoundException e) {
-      logWriter.error("Exception occured", e);
+      logWriter.error("Exception occurred", e);
       fail("Entry not found although was supposed to be there");
     }
   }
@@ -91,7 +91,7 @@ public class ConcurrentFlushingAndRegionOperationsJUnitTest extends DiskRegionTe
     try {
       assertEquals("Value1", getValueOnDisk(region));
     } catch (EntryNotFoundException e) {
-      logWriter.error("Exception occured", e);
+      logWriter.error("Exception occurred", e);
       fail("Entry not found although was supposed to be there");
     }
   }
@@ -110,8 +110,8 @@ public class ConcurrentFlushingAndRegionOperationsJUnitTest extends DiskRegionTe
           try {
             region.destroy("Key");
           } catch (Exception e) {
-            logWriter.error("Exception occured", e);
-            fail("Exception occured when it was not supposed to occur");
+            logWriter.error("Exception occurred", e);
+            fail("Exception occurred when it was not supposed to occur");
           }
         }
         alreadyComeHere = true;
@@ -163,8 +163,8 @@ public class ConcurrentFlushingAndRegionOperationsJUnitTest extends DiskRegionTe
               Thread.currentThread().interrupt();
             }
           } catch (Exception e) {
-            logWriter.error("Exception occured", e);
-            fail("Exception occured when it was not supposed to occur");
+            logWriter.error("Exception occurred", e);
+            fail("Exception occurred when it was not supposed to occur");
           }
         }
         alreadyComeHere = true;
@@ -179,7 +179,7 @@ public class ConcurrentFlushingAndRegionOperationsJUnitTest extends DiskRegionTe
           region.wait();
         }
       } catch (InterruptedException e) {
-        logWriter.error("Exception occured", e);
+        logWriter.error("Exception occurred", e);
         fail("interrupted");
       }
     }
@@ -207,8 +207,8 @@ public class ConcurrentFlushingAndRegionOperationsJUnitTest extends DiskRegionTe
               Thread.currentThread().interrupt();
             }
           } catch (Exception e) {
-            logWriter.error("Exception occured", e);
-            fail("Exception occured when it was not supposed to occur");
+            logWriter.error("Exception occurred", e);
+            fail("Exception occurred when it was not supposed to occur");
           }
         }
         alreadyComeHere = true;
@@ -223,7 +223,7 @@ public class ConcurrentFlushingAndRegionOperationsJUnitTest extends DiskRegionTe
           region.wait();
         }
       } catch (InterruptedException e) {
-        logWriter.error("Exception occured", e);
+        logWriter.error("Exception occurred", e);
         fail("interrupted");
       }
     }
@@ -290,7 +290,7 @@ public class ConcurrentFlushingAndRegionOperationsJUnitTest extends DiskRegionTe
       // region.getCache().getLogger().info("getting value2");
       assertEquals("Value2", region.get("Key"));
     } catch (Exception e) {
-      logWriter.error("Exception occured", e);
+      logWriter.error("Exception occurred", e);
       fail("Entry not found although was supposed to be there");
     }
 
@@ -299,7 +299,7 @@ public class ConcurrentFlushingAndRegionOperationsJUnitTest extends DiskRegionTe
     try {
       assertEquals("Value2", getValueOnDisk(region));
     } catch (EntryNotFoundException e) {
-      logWriter.error("Exception occured", e);
+      logWriter.error("Exception occurred", e);
       fail("Entry not found although was supposed to be there");
     }
 
@@ -322,7 +322,7 @@ public class ConcurrentFlushingAndRegionOperationsJUnitTest extends DiskRegionTe
     try {
       assertEquals("Value1", getValueOnDisk(region));
     } catch (EntryNotFoundException e) {
-      logWriter.error("Exception occured", e);
+      logWriter.error("Exception occurred", e);
       fail("Entry not found although was supposed to be there");
     }
   }
@@ -337,7 +337,7 @@ public class ConcurrentFlushingAndRegionOperationsJUnitTest extends DiskRegionTe
 
             region.destroy("Key");
           } catch (Exception e1) {
-            logWriter.error("Exception occured", e1);
+            logWriter.error("Exception occurred", e1);
             fail("encounter exception when not expected " + e1);
           }
         }
@@ -544,11 +544,11 @@ public class ConcurrentFlushingAndRegionOperationsJUnitTest extends DiskRegionTe
           hasBeenNotified = true;
         }
       } catch (Exception e) {
-        logWriter.error("Exception occured", e);
+        logWriter.error("Exception occurred", e);
         testFailed = true;
         failureCause =
-            "Exception occured when it was not supposed to occur, due to " + e + "in Close::run";
-        fail("Exception occured when it was not supposed to occur, due to " + e);
+            "Exception occurred when it was not supposed to occur, due to " + e + "in Close::run";
+        fail("Exception occurred when it was not supposed to occur, due to " + e);
       }
     }
   }

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/internal/cache/ConcurrentRegionOperationsJUnitTest.java
----------------------------------------------------------------------
diff --git a/geode-core/src/test/java/org/apache/geode/internal/cache/ConcurrentRollingAndRegionOperationsJUnitTest.java b/geode-core/src/test/java/org/apache/geode/internal/cache/ConcurrentRollingAndRegionOperationsJUnitTest.java
index 8b36545..88e999c 100755
--- a/geode-core/src/test/java/org/apache/geode/internal/cache/ConcurrentRollingAndRegionOperationsJUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/internal/cache/ConcurrentRollingAndRegionOperationsJUnitTest.java
@@ -79,7 +79,7 @@ public class ConcurrentRollingAndRegionOperationsJUnitTest extends DiskRegionTes
     try {
       assertEquals("Value2", getValueOnDisk(region));
     } catch (EntryNotFoundException e) {
-      logWriter.error("Exception occured", e);
+      logWriter.error("Exception occurred", e);
       throw new AssertionError("Entry not found although was supposed to be there", e);
     }
   }
@@ -114,7 +114,7 @@ public class ConcurrentRollingAndRegionOperationsJUnitTest extends DiskRegionTes
       assertEquals("Value1", getValueOnDisk(region));
       assertEquals("Value1", getValueInHTree(region));
     } catch (EntryNotFoundException e) {
-      logWriter.error("Exception occured", e);
+      logWriter.error("Exception occurred", e);
       throw new AssertionError("Entry not found although was supposed to be there", e);
     }
   }
@@ -144,7 +144,7 @@ public class ConcurrentRollingAndRegionOperationsJUnitTest extends DiskRegionTes
     try {
       region.destroy("Key");
     } catch (Exception e) {
-      logWriter.error("Exception occured", e);
+      logWriter.error("Exception occurred", e);
       throw new AssertionError("failed while trying to destroy due to ", e);
     }
     boolean entryNotFound = false;
@@ -239,7 +239,7 @@ public class ConcurrentRollingAndRegionOperationsJUnitTest extends DiskRegionTes
     try {
       assertEquals("Value2", getValueOnDisk(region));
     } catch (EntryNotFoundException e) {
-      logWriter.error("Exception occured", e);
+      logWriter.error("Exception occurred", e);
       throw new AssertionError("Entry not found although was supposed to be there", e);
     }
   }
@@ -271,7 +271,7 @@ public class ConcurrentRollingAndRegionOperationsJUnitTest extends DiskRegionTes
       assertEquals("Value1", getValueOnDisk(region));
       assertEquals("Value1", getValueInHTree(region));
     } catch (EntryNotFoundException e) {
-      logWriter.error("Exception occured", e);
+      logWriter.error("Exception occurred", e);
       throw new AssertionError("Entry not found although was supposed to be there", e);
     }
   }
@@ -301,7 +301,7 @@ public class ConcurrentRollingAndRegionOperationsJUnitTest extends DiskRegionTes
     try {
       region.destroy("Key");
     } catch (Exception e1) {
-      logWriter.error("Exception occured", e1);
+      logWriter.error("Exception occurred", e1);
       throw new AssertionError("encounter exception when not expected ", e1);
     }
     boolean entryNotFound = false;
@@ -663,7 +663,7 @@ public class ConcurrentRollingAndRegionOperationsJUnitTest extends DiskRegionTes
                 Thread.sleep(2000);
               } catch (InterruptedException e) {
                 testFailed = true;
-                failureCause = "Exception occured when it was not supposed to occur, Exception is "
+                failureCause = "Exception occurred when it was not supposed to occur, Exception is "
                     + e + "in concurrentPutAndRoll";
                 throw new AssertionError("exception not expected here", e);
               }
@@ -679,7 +679,7 @@ public class ConcurrentRollingAndRegionOperationsJUnitTest extends DiskRegionTes
             }
           } catch (InterruptedException e) {
             testFailed = true;
-            failureCause = "Exception occured when it was not supposed to occur, Exception is " + e
+            failureCause = "Exception occurred when it was not supposed to occur, Exception is " + e
                 + "in concurrentPutAndRoll";
             throw new AssertionError("exception not expected here", e);
           }
@@ -819,8 +819,8 @@ public class ConcurrentRollingAndRegionOperationsJUnitTest extends DiskRegionTes
           th.start();
           Thread.sleep(3000);
         } catch (Exception e) {
-          logWriter.error("Exception occured", e);
-          throw new AssertionError("Exception occured when it was not supposed to occur", e);
+          logWriter.error("Exception occurred", e);
+          throw new AssertionError("Exception occurred when it was not supposed to occur", e);
         }
       }
     });
@@ -856,8 +856,8 @@ public class ConcurrentRollingAndRegionOperationsJUnitTest extends DiskRegionTes
           th.start();
           Thread.sleep(3000);
         } catch (Exception e) {
-          logWriter.error("Exception occured", e);
-          throw new AssertionError("Exception occured when it was not supposed to occur", e);
+          logWriter.error("Exception occurred", e);
+          throw new AssertionError("Exception occurred when it was not supposed to occur", e);
         }
       }
     });
@@ -898,10 +898,11 @@ public class ConcurrentRollingAndRegionOperationsJUnitTest extends DiskRegionTes
           hasBeenNotified = true;
         }
       } catch (Exception e) {
-        logWriter.error("Exception occured", e);
+        logWriter.error("Exception occurred", e);
         testFailed = true;
-        failureCause = "Exception occured when it was not supposed to occur, due to " + e;
-        throw new AssertionError("Exception occured when it was not supposed to occur, due to ", e);
+        failureCause = "Exception occurred when it was not supposed to occur, due to " + e;
+        throw new AssertionError("Exception occurred when it was not supposed to occur, due to ",
+            e);
       }
     }
   }
diff --git a/geode-core/src/main/java/org/apache/geode/internal/cache/wan/GatewayReceiverStats.java b/geode-core/src/main/java/org/apache/geode/internal/cache/wan/GatewayReceiverStats.java
index ca345a9..0561b4f 100644
--- a/geode-core/src/main/java/org/apache/geode/internal/cache/wan/GatewayReceiverStats.java
+++ b/geode-core/src/main/java/org/apache/geode/internal/cache/wan/GatewayReceiverStats.java
@@ -54,7 +54,7 @@ public class GatewayReceiverStats extends CacheServerStats {
   private static final String UNKNOWN_OPERATIONS_RECEIVED = "unknowsOperationsReceived";
 
   /** Name of the unprocessed events added by primary statistic */
-  private static final String EXCEPTIONS_OCCURED = "exceptionsOccured";
+  private static final String EXCEPTIONS_OCCURRED = "exceptionsOccurred";
 
   // /** Id of the events queued statistic */
   // private int failoverBatchesReceivedId;
@@ -84,7 +84,7 @@ public class GatewayReceiverStats extends CacheServerStats {
   private int unknowsOperationsReceivedId;
 
   /** Id of the unprocessed events added by primary statistic */
-  private int exceptionsOccuredId;
+  private int exceptionsOccurredId;
 
   // ///////////////////// Constructors ///////////////////////
 
@@ -109,8 +109,8 @@ public class GatewayReceiverStats extends CacheServerStats {
             "total number of destroy operations received by this GatewayReceiver", "operations"),
         f.createIntCounter(UNKNOWN_OPERATIONS_RECEIVED,
             "total number of unknown operations received by this GatewayReceiver", "operations"),
-        f.createIntCounter(EXCEPTIONS_OCCURED,
-            "number of exceptions occured while porcessing the batches", "operations")};
+        f.createIntCounter(EXCEPTIONS_OCCURRED,
+            "number of exceptions occurred while porcessing the batches", "operations")};
     return new GatewayReceiverStats(f, ownerName, typeName, descriptors);
 
   }
@@ -128,7 +128,7 @@ public class GatewayReceiverStats extends CacheServerStats {
     updateRequestId = statType.nameToId(UPDATE_REQUESTS);
     destroyRequestId = statType.nameToId(DESTROY_REQUESTS);
     unknowsOperationsReceivedId = statType.nameToId(UNKNOWN_OPERATIONS_RECEIVED);
-    exceptionsOccuredId = statType.nameToId(EXCEPTIONS_OCCURED);
+    exceptionsOccurredId = statType.nameToId(EXCEPTIONS_OCCURRED);
   }
 
   // /////////////////// Instance Methods /////////////////////
@@ -233,14 +233,14 @@ public class GatewayReceiverStats extends CacheServerStats {
   }
 
   /**
    * Increments the number of exceptions occured by 1.
    */
-  public void incExceptionsOccured() {
-    this.stats.incInt(exceptionsOccuredId, 1);
+  public void incExceptionsOccurred() {
+    this.stats.incInt(exceptionsOccurredId, 1);
   }
 
-  public int getExceptionsOccured() {
-    return this.stats.getInt(exceptionsOccuredId);
+  public int getExceptionsOccurred() {
+    return this.stats.getInt(exceptionsOccurredId);
   }
 
   /**

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/main/java/org/apache/geode/internal/cache/wan/parallel/ParallelQueueBatchRemovalMessage.java
----------------------------------------------------------------------
@@ -233,14 +233,14 @@ public class GatewayReceiverStats extends CacheServerStats {
 
   /**
-   * Increments the number of exceptions occured by 1.
+   * Increments the number of exceptions occurred by 1.
    */
diff --git a/geode-core/src/test/java/org/apache/geode/internal/cache/ConcurrentRegionOperationsJUnitTest.java b/geode-core/src/test/java/org/apache/geode/internal/cache/ConcurrentRegionOperationsJUnitTest.java
index 643c8c9..d5cd508 100755
--- a/geode-core/src/test/java/org/apache/geode/internal/cache/ConcurrentRegionOperationsJUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/internal/cache/ConcurrentRegionOperationsJUnitTest.java
@@ -70,15 +70,15 @@ public class ConcurrentRegionOperationsJUnitTest extends DiskRegionTestingBase {
    */
   protected int TIME_TO_RUN = 1000;
 
-  private boolean exceptionOccuredInPuts = false;
+  private boolean exceptionOccurredInPuts = false;
 
-  private boolean exceptionOccuredInGets = false;
+  private boolean exceptionOccurredInGets = false;
 
-  private boolean exceptionOccuredInDestroys = false;
+  private boolean exceptionOccurredInDestroys = false;
 
-  private boolean exceptionOccuredInClears = false;
+  private boolean exceptionOccurredInClears = false;
 
-  protected boolean exceptionOccuredInForceRolls = false;
+  protected boolean exceptionOccurredInForceRolls = false;
 
   // if this test is to run for a longer time, make this true
   private static final boolean longTest = false;
@@ -330,13 +330,13 @@ public class ConcurrentRegionOperationsJUnitTest extends DiskRegionTestingBase {
       try {
         region.get("" + 1);
       } catch (Exception e) {
-        logWriter.severe("Exception occured  ", e);
+        logWriter.severe("Exception occurred  ", e);
         fail(
             "Failed to retrieve value from disk as the Oplog has been rolled but entry still references the Oplog.");
       }
 
     } catch (Exception e) {
-      logWriter.severe("Exception occured  ", e);
+      logWriter.severe("Exception occurred  ", e);
       fail("Test failed because  of unexpected exception");
     }
 
@@ -518,23 +518,23 @@ public class ConcurrentRegionOperationsJUnitTest extends DiskRegionTestingBase {
     }
     r1.close();
 
-    if (exceptionOccuredInDestroys) {
-      fail("Exception occured while destroying");
+    if (exceptionOccurredInDestroys) {
+      fail("Exception occurred while destroying");
     }
-    if (exceptionOccuredInClears) {
-      fail("Exception occured while clearing");
+    if (exceptionOccurredInClears) {
+      fail("Exception occurred while clearing");
     }
 
-    if (exceptionOccuredInForceRolls) {
-      fail("Exception occured while force Rolling");
+    if (exceptionOccurredInForceRolls) {
+      fail("Exception occurred while force Rolling");
     }
 
-    if (exceptionOccuredInGets) {
-      fail("Exception occured while doing gets");
+    if (exceptionOccurredInGets) {
+      fail("Exception occurred while doing gets");
     }
 
-    if (exceptionOccuredInPuts) {
-      fail("Exception occured while doing puts");
+    if (exceptionOccurredInPuts) {
+      fail("Exception occurred while doing puts");
     }
 
     return region2;
@@ -590,8 +590,8 @@ public class ConcurrentRegionOperationsJUnitTest extends DiskRegionTestingBase {
           expected = region2.put(integer1, integer2);
         }
       } catch (Exception e) {
-        exceptionOccuredInPuts = true;
-        logWriter.severe("Exception occured in puts ", e);
+        exceptionOccurredInPuts = true;
+        logWriter.severe("Exception occurred in puts ", e);
         fail(" failed during put due to " + e);
       }
     } finally {
@@ -627,8 +627,8 @@ public class ConcurrentRegionOperationsJUnitTest extends DiskRegionTestingBase {
           expected = region2.get(integer1);
         }
       } catch (Exception e) {
-        exceptionOccuredInGets = true;
-        logWriter.severe("Exception occured in get ", e);
+        exceptionOccurredInGets = true;
+        logWriter.severe("Exception occurred in get ", e);
         throw new AssertionError(" failed during get due to ", e);
       }
     } finally {
@@ -642,8 +642,8 @@ public class ConcurrentRegionOperationsJUnitTest extends DiskRegionTestingBase {
   }
 
   void destroy() {
-    Exception exceptionOccured1 = null;
-    Exception exceptionOccured2 = null;
+    Exception exceptionOccurred1 = null;
+    Exception exceptionOccurred2 = null;
     int randomInt1 = random.nextInt() % 10;
     if (randomInt1 < 0) {
       randomInt1 = randomInt1 * (-1);
@@ -660,20 +660,20 @@ public class ConcurrentRegionOperationsJUnitTest extends DiskRegionTestingBase {
       try {
         v = region1.destroy(integer1);
       } catch (Exception e) {
-        exceptionOccured1 = e;
+        exceptionOccurred1 = e;
       }
       if (this.validate) {
         try {
           expected = region2.destroy(integer1);
         } catch (Exception e) {
-          exceptionOccured2 = e;
+          exceptionOccurred2 = e;
         }
 
-        if ((exceptionOccured1 != null) ^ (exceptionOccured2 != null)) {
-          exceptionOccuredInDestroys = true;
-          logWriter.severe("Exception occured in destroy ex1=" + exceptionOccured1 + " ex2="
-              + exceptionOccured2);
-          fail("Exception occured in destroy");
+        if ((exceptionOccurred1 != null) ^ (exceptionOccurred2 != null)) {
+          exceptionOccurredInDestroys = true;
+          logWriter.severe("Exception occurred in destroy ex1=" + exceptionOccurred1 + " ex2="
+              + exceptionOccurred2);
+          fail("Exception occurred in destroy");
         }
       }
     } finally {
@@ -696,15 +696,15 @@ public class ConcurrentRegionOperationsJUnitTest extends DiskRegionTestingBase {
     try {
       region1.clear();
     } catch (Exception e) {
-      exceptionOccuredInClears = true;
-      logWriter.severe("Exception occured in clear=", e);
-      throw new AssertionError("Exception occured in clear", e);
+      exceptionOccurredInClears = true;
+      logWriter.severe("Exception occurred in clear=", e);
+      throw new AssertionError("Exception occurred in clear", e);
     }
   }
 
   /**
    * Bug Test for bug # 35139. This bug was occuring because a clear & region destroy operation
    * occured near concurrently. The region destroy operation notified the roller thread to stop &
    * then it joined with the roller . But by that time clear operation created a new instance of
    * roller thread ( because a clear operation stop/starts the roller) & the destroy operation
    * actually joined with the new thread ( different from the one on which notification was issued
@@ -824,9 +824,9 @@ public class ConcurrentRegionOperationsJUnitTest extends DiskRegionTestingBase {
       try {
         region1.forceRolling();
       } catch (Exception e) {
-        exceptionOccuredInForceRolls = true;
-        logWriter.severe("Exception occured in forceRolling ", e);
-        throw new AssertionError(" Exception occured here", e);
+        exceptionOccurredInForceRolls = true;
+        logWriter.severe("Exception occurred in forceRolling ", e);
+        throw new AssertionError(" Exception occurred here", e);
       }
     }
 

http://git-wip-us.apache.org/repos/asf/geode/blob/05d80689/geode-core/src/test/java/org/apache/geode/internal/cache/ConcurrentRollingAndRegionOperationsJUnitTest.java
----------------------------------------------------------------------
@@ -696,15 +696,15 @@ public class ConcurrentRegionOperationsJUnitTest extends DiskRegionTestingBase {
   /**
    * Bug Test for bug # 35139. This bug was occuring because a clear & region destroy operation
-   * occured near concurrently. The region destroy operation notified the roller thread to stop &
+   * occurred near concurrently. The region destroy operation notified the roller thread to stop &
    * then it joined with the roller . But by that time clear operation created a new instance of
    * roller thread ( because a clear operation stop/starts the roller) & the destroy operation